ConnectionMeta

Struct ConnectionMeta 

pub struct ConnectionMeta {
    pub created_at: Instant,
    pub last_used: Instant,
    pub is_broken: bool,
}
Metadata for a pooled connection — used for idle timeout and max lifetime.

Fields

created_at: Instant

When this connection was created.

last_used: Instant

When this connection was last returned to the pool.

is_broken: bool

Flag set when an I/O error occurs — marks connection as broken.

Implementations

Source

impl ConnectionMeta

pub fn new() -> Self

pub fn touch(&mut self)

Mark this connection as recently used (returned to pool).

pub fn is_idle_expired(&self, timeout: Duration) -> bool

Check if the connection has exceeded the idle timeout.

pub fn is_lifetime_expired(&self, max_lifetime: Duration) -> bool

Check if the connection has exceeded its max lifetime.