pub struct ConnectionMeta {
pub created_at: Instant,
pub last_used: Instant,
pub is_broken: bool,
}Expand description
Metadata for a pooled connection — used for idle timeout and max lifetime.
Fields
created_at: InstantWhen this connection was created.
last_used: InstantWhen this connection was last returned to the pool.
is_broken: boolFlag set when an I/O error occurs — marks connection as broken.
Implementations
Sourceimpl ConnectionMeta
impl ConnectionMeta
pub fn new() -> Self
Sourcepub fn is_idle_expired(&self, timeout: Duration) -> bool
pub fn is_idle_expired(&self, timeout: Duration) -> bool
Check if the connection has exceeded the idle timeout.
Sourcepub fn is_lifetime_expired(&self, max_lifetime: Duration) -> bool
pub fn is_lifetime_expired(&self, max_lifetime: Duration) -> bool
Check if the connection has exceeded its max lifetime.