pub fn decode(msg_type: u8, body: Bytes) -> Result<BackendMessage>Expand description
Decode a single backend message from a raw frame.
msg_type is the first byte, body is the payload (after the length).
pub fn decode(msg_type: u8, body: Bytes) -> Result<BackendMessage>Decode a single backend message from a raw frame.
msg_type is the first byte, body is the payload (after the length).